@@ -1,6 +1,4 @@
 import os
-import re
-import time
 import threading
 import subprocess
 import paramiko
